==> gravitino-1.0.0-src.tar.gz: gravitino-1.0.0-src/iceberg/iceberg-rest-server/src/main/java/org/apache/gravitino/listener/api/event/IcebergCreateNamespaceEvent.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.gravitino.listener.api.event;

import org.apache.gravitino.NameIdentifier;
import org.apache.gravitino.annotation.DeveloperApi;
import org.apache.gravitino.iceberg.service.IcebergRestUtils;
import org.apache.iceberg.rest.requests.CreateNamespaceRequest;
import org.apache.iceberg.rest.responses.CreateNamespaceResponse;

/** Represent an event after creating Iceberg namespace successfully. */
@DeveloperApi
public class IcebergCreateNamespaceEvent extends IcebergNamespaceEvent {

  private final CreateNamespaceRequest createNamespaceRequest;
  private final CreateNamespaceResponse createNamespaceResponse;

  public IcebergCreateNamespaceEvent(
      IcebergRequestContext icebergRequestContext,
      NameIdentifier nameIdentifier,
      CreateNamespaceRequest createNamespaceRequest,
      CreateNamespaceResponse createNamespaceResponse) {
    super(icebergRequestContext, nameIdentifier);
    this.createNamespaceRequest =
        IcebergRestUtils.cloneIcebergRESTObject(
            createNamespaceRequest, CreateNamespaceRequest.class);
    this.createNamespaceResponse =
        IcebergRestUtils.cloneIcebergRESTObject(
            createNamespaceResponse, CreateNamespaceResponse.class);
  }

  public CreateNamespaceRequest createNamespaceRequest() {
    return createNamespaceRequest;
  }

  public CreateNamespaceResponse createNamespaceResponse() {
    return createNamespaceResponse;
  }

  @Override
  public OperationType operationType() {
    return OperationType.CREATE_SCHEMA;
  }
}

==> gravitino-1.1.0-src.tar.gz: gravitino-1.1.0-src/iceberg/iceberg-rest-server/src/main/java/org/apache/gravitino/listener/api/event/IcebergCreateNamespaceEvent.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.gravitino.listener.api.event;

import org.apache.gravitino.NameIdentifier;
import org.apache.gravitino.annotation.DeveloperApi;
import org.apache.gravitino.iceberg.service.IcebergRESTUtils;
import org.apache.iceberg.rest.requests.CreateNamespaceRequest;
import org.apache.iceberg.rest.responses.CreateNamespaceResponse;

/** Represent an event after creating Iceberg namespace successfully. */
@DeveloperApi
public class IcebergCreateNamespaceEvent extends IcebergNamespaceEvent {

  private final CreateNamespaceRequest createNamespaceRequest;
  private final CreateNamespaceResponse createNamespaceResponse;

  public IcebergCreateNamespaceEvent(
      IcebergRequestContext icebergRequestContext,
      NameIdentifier nameIdentifier,
      CreateNamespaceRequest createNamespaceRequest,
      CreateNamespaceResponse createNamespaceResponse) {
    super(icebergRequestContext, nameIdentifier);
    this.createNamespaceRequest =
        IcebergRESTUtils.cloneIcebergRESTObject(
            createNamespaceRequest, CreateNamespaceRequest.class);
    this.createNamespaceResponse =
        IcebergRESTUtils.cloneIcebergRESTObject(
            createNamespaceResponse, CreateNamespaceResponse.class);
  }

  public CreateNamespaceRequest createNamespaceRequest() {
    return createNamespaceRequest;
  }

  public CreateNamespaceResponse createNamespaceResponse() {
    return createNamespaceResponse;
  }

  @Override
  public OperationType operationType() {
    return OperationType.CREATE_SCHEMA;
  }
}
